| calculate_dataset | R Documentation |
Validates a dataset, creates an immutable deterministic run directory and writes six structured output workbooks plus a JSON run manifest.
calculate_dataset(dataset)
dataset |
Dataset directory containing an |
Output is written below dataset/outputs/<run-id>. The run ID
fingerprints the input files, code and package version.
An rwa_calculation_result object with output paths.
validate_dataset(), generate_synthetic_dataset()
root <- file.path(tempdir(), "rwa-calculation-example")
dataset <- generate_synthetic_dataset(root, bank_profile = "KSA_BANK")
calculate_dataset(dataset)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.