| list_reference_profiles | R Documentation |
Returns metadata for every synthetic reference profile included with the package. No customer or production data is included.
list_reference_profiles()
A data frame with profile identifiers, versions, base dates, seeds, default dataset versions and descriptions.
list_reference_profiles()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.